/*
*  Copyright (c) 2013 The WebRTC project authors. All Rights Reserved.
*
*  Use of this source code is governed by a BSD-style license
*  that can be found in the LICENSE file in the root of the source
*  tree. An additional intellectual property rights grant can be found
*  in the file PATENTS.  All contributing project authors may
*  be found in the AUTHORS file in the root of the source tree.
*/
#include "webrtc/modules/desktop_capture/app_capturer.h"
#include "webrtc/modules/desktop_capture/desktop_capturer.h"

#include <assert.h>

#include "webrtc/modules/desktop_capture/desktop_frame.h"

namespace webrtc {

namespace {

class AppCapturerNull : public AppCapturer {
public:
  AppCapturerNull();
  virtual ~AppCapturerNull();

  // AppCapturer interface.
  virtual bool GetAppList(AppList* apps) override;
  virtual bool SelectApp(ProcessId id) override;
  virtual bool BringAppToFront()	override;

  // DesktopCapturer interface.
  void Start(Callback* callback) override;
  void Stop() override;
  void CaptureFrame() override;
  bool GetSourceList(SourceList* sources) override;
  bool SelectSource(SourceId id) override;

private:
  Callback* callback_;

  RTC_DISALLOW_COPY_AND_ASSIGN(AppCapturerNull);
};

AppCapturerNull::AppCapturerNull()
  : callback_(NULL) {
}

AppCapturerNull::~AppCapturerNull() {
}

bool AppCapturerNull::GetAppList(AppList* apps) {
  // Not implemented yet: See Bug 1036653
  return false;
}

bool AppCapturerNull::SelectApp(ProcessId id) {
  // Not implemented yet: See Bug 1036653
  return false;
}

bool AppCapturerNull::BringAppToFront() {
  // Not implemented yet: See Bug 1036653
  return false;
}

bool AppCapturerNull::GetSourceList(SourceList* sources) {
  // Not implemented yet.
  return false;
}

bool AppCapturerNull::SelectSource(SourceId id) {
  // Not implemented yet.
  return false;
}

void AppCapturerNull::Start(Callback* callback) {
  assert(!callback_);
  assert(callback);

  callback_ = callback;
}

void AppCapturerNull::Stop() {
  callback_ = NULL;
}

void AppCapturerNull::CaptureFrame() {
  // Not implemented yet.
  callback_->OnCaptureResult(Result::ERROR_TEMPORARY, nullptr);
}

}  // namespace

#if not defined(USE_PIPEWIRE)
// static
std::unique_ptr<DesktopCapturer> DesktopCapturer::CreateRawAppCapturer(
    const DesktopCaptureOptions& options) {
  return std::unique_ptr<DesktopCapturer>(new AppCapturerNull());
}
#endif // not defined(USE_PIPEWIRE)

}  // namespace webrtc
